# PIPWeb
![PyPI Release](https://github.com/TechGeeks-Dev/PIPWeb/actions/workflows/PyPI-Release.yml/badge.svg)
### What is PIPWeb ?
**PIPWeb** is a free & OpenSource Python PIP Web Installer.

### How to Install ?
To Install **PIPWeb**, You need to run `pip install PIPWeb` from a Terminal and then `pipweb run` from that or another Terminal and it will open the Default Browser to PIPWeb (Make sure that nothing is running at port 9999 as PIPWeb uses it)